@@ -52,6 +52,27 @@ def has_perm_administration(func, *args, **kwargs):
     raise AccessControlError("The user doesn't have enough rights.")
 
 
+def is_superuser(func, *args, **kwargs):
+    """Is the user a superuser.
+
+    Args:
+        func:
+        *args:
+        **kwargs:
+
+    Returns:
+
+    """
+    try:
+        request = kwargs["request"]
+        if request and request.user.is_superuser:
+            return func(*args, **kwargs)
+    except Exception as e:
+        logger.warning("has_perm_administration threw an exception: ".format(str(e)))
+
+    raise AccessControlError("The user doesn't have enough rights.")
+
+
 def check_can_write(document, user):
     """Check that the user can write.
 
@@ -62,11 +83,18 @@ def check_can_write(document, user):
     Returns:
 
     """
-    # TODO: data will inherit of workspace rights, which means a owner can't edit or delete a data if data in wkp that doesn't give hin write rights
+    # Raise error if anonymous user
+    if user.is_anonymous:
+        raise AccessControlError("Unable to write if not authenticated.")
+
+    # TODO: data will inherit of workspace rights, which means a owner can't edit
+    #  or delete a data if data in wkp that doesn't give hin write rights
     if hasattr(document, "workspace") and document.workspace is not None:
-        if workspace_api.is_workspace_public(document.workspace):
+        if workspace_api.is_workspace_public(
+            document.workspace
+        ) and document.user_id == str(user.id):
             has_perm_publish(user, rights.publish_data)
-        else:
+        else:  # Workspace not public OR editing someone else's data.
             _check_can_write_in_workspace(document.workspace, user)
 
     # not the owner and workspace is not set or None
@@ -234,6 +262,41 @@ def can_write(func, document, user):
     return func(document, user)
 
 
+def can_request_write(func, document, request):
+    """Can user request write
+
+    Args:
+        func:
+        document:
+        request:
+
+    Returns:
+
+    """
+    if request.user.is_superuser:
+        return func(document, request)
+
+    check_can_write(document, request.user)
+    return func(document, request)
+
+
+def can_anonymous_access_public_data(func, *args, **kwargs):
+    """Can anonymous access a public data
+
+    Args:
+        func:
+        *args:
+        **kwargs:
+
+    Returns:
+
+    """
+    user = next((arg for arg in args if isinstance(arg, User)), None)
+
+    _check_anonymous_access(user)
+    return func(*args, **kwargs)
+
+
 def _check_can_write_in_workspace(workspace, user):
     """Check that user can write in the workspace.
 
@@ -277,6 +340,20 @@ def _check_can_read_or_write_in_workspace(workspace, user):
         )
 
 
+def _check_anonymous_access(user):
+    """Check anonymous access
+
+    Args:
+        user:
+
+    Returns:
+    """
+    if (user is None or user.is_anonymous) and not CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT:
+        raise AccessControlError(
+            "The user doesn't have enough rights to access this document."
+        )
+
+
 def _check_can_read(document, user):
     """Check that the user can read.
 
@@ -287,11 +364,7 @@ def _check_can_read(document, user):
     Returns:
 
     """
-    # anonymous user case
-    if user.is_anonymous and not CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT:
-        raise AccessControlError(
-            "The user doesn't have enough rights to access this document."
-        )
+    _check_anonymous_access(user)
 
     # workspace case
     if document.user_id != str(user.id):
@@ -309,7 +382,7 @@ def _check_can_read(document, user):
         # workspace is not set
         else:
             raise AccessControlError(
-                "The user doesn't have enough rights to access this."
+                "The user doesn't have enough rights to access this document."
             )
 
 
