@@ -3,8 +3,7 @@
 
 
 class AccessControlError(Exception):
-    """ Exception raised when checking access control
-    """
+    """Exception raised when checking access control"""
 
     def __init__(self, message):
         self.message = message
