@@ -91,3 +91,10 @@ class SSLError(Exception):
 
     def __init__(self, message):
         self.message = message
+
+
+class QueryError(Exception):
+    """Exception raised when an error occurs during a query."""
+
+    def __init__(self, message):
+        self.message = message
