@@ -4,8 +4,7 @@ from rest_framework.serializers import Serializer
 
 
 class BasicSerializer(Serializer):
-    """ Represent a serializer with a basic implementation of the abstract methods create and update.
-    """
+    """Represent a serializer with a basic implementation of the abstract methods create and update."""
 
     def create(self, validated_data):
         pass
