@@ -2,13 +2,19 @@
 """
 from io import BytesIO
 
+from django_mongoengine import fields, Document
+from mongoengine import errors as mongoengine_errors
+
+from core_main_app.commons import exceptions
 from core_main_app.settings import (
     GRIDFS_DATA_COLLECTION,
     SEARCHABLE_DATA_OCCURRENCES_LIMIT,
+    XML_POST_PROCESSOR,
+    XML_FORCE_LIST,
 )
 from core_main_app.utils import xml as xml_utils
+from core_main_app.utils.datetime_tools.utils import datetime_now
 from core_main_app.utils.validation.regex_validation import not_empty_or_whitespaces
-from django_mongoengine import fields, Document
 
 
 class AbstractData(Document):
@@ -16,8 +22,10 @@ class AbstractData(Document):
 
     dict_content = fields.DictField(blank=True)
     title = fields.StringField(blank=False, validation=not_empty_or_whitespaces)
-    last_modification_date = fields.DateTimeField(blank=True, default=None)
     xml_file = fields.FileField(blank=False, collection_name=GRIDFS_DATA_COLLECTION)
+    creation_date = fields.DateTimeField(blank=True, default=None)
+    last_modification_date = fields.DateTimeField(blank=True, default=None)
+    last_change_date = fields.DateTimeField(blank=True, default=None)
 
     _xml_content = None
 
@@ -55,6 +63,9 @@ class AbstractData(Document):
         Returns:
 
         """
+        # update modification times
+        self.last_modification_date = datetime_now()
+        # update content
         self._xml_content = value
 
     def convert_and_save(self):
@@ -66,7 +77,7 @@ class AbstractData(Document):
         self.convert_to_dict()
         self.convert_to_file()
 
-        return self.save()
+        return self.save_object()
 
     def convert_to_dict(self):
         """Convert the xml contained in xml_content into a dictionary.
@@ -76,7 +87,9 @@ class AbstractData(Document):
         """
         # transform xml content into a dictionary
         dict_content = xml_utils.raw_xml_to_dict(
-            self.xml_content, xml_utils.post_processor
+            self.xml_content,
+            postprocessor=XML_POST_PROCESSOR,
+            force_list=XML_FORCE_LIST,
         )
         # if limit on element occurrences is set
         if SEARCHABLE_DATA_OCCURRENCES_LIMIT is not None:
@@ -104,3 +117,25 @@ class AbstractData(Document):
         else:
             # editing (self.xml_file gets a new id)
             self.xml_file.replace(xml_file, content_type="application/xml")
+
+    def save_object(self):
+        """Custom save. Set the datetime fields and save.
+
+        Returns:
+
+        """
+        try:
+            # initialize times
+            now = datetime_now()
+            # update change date every time the data is updated
+            self.last_change_date = now
+            if not self.id:
+                # initialize when first created
+                self.creation_date = now
+                # initialize when first saved, then only updates when content is updated
+                self.last_modification_date = now
+            return self.save()
+        except mongoengine_errors.NotUniqueError as e:
+            raise exceptions.NotUniqueError(e)
+        except Exception as ex:
+            raise exceptions.ModelError(ex)
