@@ -1,24 +1,28 @@
 """ BLOB API
 """
 import core_main_app.commons.exceptions as exceptions
+from core_main_app.access_control.api import can_change_owner
 from core_main_app.access_control.api import (
     has_perm_administration,
     can_read_or_write_in_workspace,
-    can_read,
     can_read_id,
     can_write,
 )
 from core_main_app.access_control.decorators import access_control
-from core_main_app.components.blob.access_control import can_write_blob_workspace
+from core_main_app.components.blob.access_control import (
+    can_write_blob_workspace,
+    can_write_blob,
+)
 from core_main_app.components.blob.models import Blob
-from core_main_app.access_control.api import can_change_owner
 
 
-def insert(blob):
+@access_control(can_write_blob)
+def insert(blob, user):
     """Insert the blob in the blob repository.
 
     Args:
         blob:
+        user:
 
     Returns:
 
