@@ -2,21 +2,20 @@
 """
 import core_main_app.access_control.api
 import core_main_app.components.workspace.access_control
-from core_main_app.access_control.api import has_perm_administration
 from core_main_app.access_control import api as access_control_api
+from core_main_app.access_control.api import has_perm_administration, is_superuser
 from core_main_app.access_control.decorators import access_control
 from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.data import access_control as data_api_access_control
 from core_main_app.components.data.models import Data
-from core_main_app.components.workspace import api as workspace_api
-from core_main_app.settings import DATA_SORTING_FIELDS
-from core_main_app.utils.datetime_tools.utils import datetime_now
-from core_main_app.utils.xml import validate_xml_data
 from core_main_app.components.data.tasks import (
     async_migration_task,
     async_template_migration_task,
 )
-
+from core_main_app.components.workspace import api as workspace_api
+from core_main_app.settings import DATA_SORTING_FIELDS
+from core_main_app.utils.datetime_tools.utils import datetime_now
+from core_main_app.utils.xml import validate_xml_data
 from xml_utils.xsd_tree.xsd_tree import XSDTree
 
 
@@ -74,25 +73,6 @@ def get_all(user, order_by_field=DATA_SORTING_FIELDS):
     return Data.get_all(order_by_field)
 
 
-def get_all_accessible_by_user(user, order_by_field=DATA_SORTING_FIELDS):
-    """Return all data accessible by a user.
-
-    Parameters:
-        user:
-        order_by_field:
-
-    Returns: data collection
-    """
-
-    read_workspaces = workspace_api.get_all_workspaces_with_read_access_by_user(user)
-    write_workspaces = workspace_api.get_all_workspaces_with_write_access_by_user(user)
-    user_accessible_workspaces = list(set().union(read_workspaces, write_workspaces))
-
-    return Data.get_all_by_user_and_workspace(
-        user.id, user_accessible_workspaces, order_by_field
-    )
-
-
 def get_all_by_user(user, order_by_field=DATA_SORTING_FIELDS):
     """Return all data owned by a user.
 
@@ -118,13 +98,13 @@ def get_all_except_user(user, order_by_field=DATA_SORTING_FIELDS):
     return Data.get_all_except_user_id(str(user.id), order_by_field)
 
 
-@access_control(core_main_app.access_control.api.can_write)
-def upsert(data, user):
+@access_control(core_main_app.access_control.api.can_request_write)
+def upsert(data, request):
     """Save or update the data.
 
     Args:
         data:
-        user:
+        request:
 
     Returns:
 
@@ -132,19 +112,17 @@ def upsert(data, user):
     if data.xml_content is None:
         raise exceptions.ApiError("Unable to save data: xml_content field is not set.")
 
-    data.last_modification_date = datetime_now()
-
-    check_xml_file_is_valid(data)
+    check_xml_file_is_valid(data, request=request)
     return data.convert_and_save()
 
 
-@access_control(has_perm_administration)
-def admin_insert(data, user):
+@access_control(is_superuser)
+def admin_insert(data, request):
     """Save the data.
 
     Args:
         data:
-        user:
+        request:
 
     Returns:
 
@@ -152,18 +130,28 @@ def admin_insert(data, user):
     if data.xml_content is None:
         raise exceptions.ApiError("Unable to save data: xml_content field is not set.")
 
+    # initialize times - use values if provided, set now otherwise
+    now = datetime_now()
+    if not data.creation_date:
+        data.creation_date = now
     if not data.last_modification_date:
-        data.last_modification_date = datetime_now()
+        data.last_modification_date = now
+    if not data.last_change_date:
+        data.last_change_date = now
 
-    check_xml_file_is_valid(data)
-    return data.convert_and_save()
+    # convert and save the data (do not call convert_and_save that will set the date fields)
+    check_xml_file_is_valid(data, request=request)
+    data.convert_to_file()
+    data.convert_to_dict()
+    return data.save()
 
 
-def check_xml_file_is_valid(data):
+def check_xml_file_is_valid(data, request=None):
     """Check if xml data is valid against a given schema.
 
     Args:
         data:
+        request:
 
     Returns:
 
@@ -174,13 +162,11 @@ def check_xml_file_is_valid(data):
         xml_tree = XSDTree.build_tree(data.xml_content)
     except Exception as e:
         raise exceptions.XMLError(str(e))
-
     try:
         xsd_tree = XSDTree.build_tree(template.content)
     except Exception as e:
         raise exceptions.XSDError(str(e))
-
-    error = validate_xml_data(xsd_tree, xml_tree)
+    error = validate_xml_data(xsd_tree, xml_tree, request=request)
     if error is not None:
         raise exceptions.XMLError(error)
     else:
@@ -229,7 +215,7 @@ def change_owner(data, new_user, user):
     """
     # FIXME: user can transfer data to anybody, too permissive
     data.user_id = str(new_user.id)
-    data.save()
+    data.save_object()
 
 
 def get_none():
@@ -283,17 +269,18 @@ def assign(data, workspace, user):
 
     """
     data.workspace = workspace
-    return data.save()
+    return data.save_object()
 
 
 @access_control(has_perm_administration)
-def migrate_data_list(data_list, target_template_id, migrate, user):
+def migrate_data_list(data_list, xslt_id, target_template_id, migrate, user):
     """Perform a migration / validation of the data list for the given target template id
     NB: This action is executed with an async task, use the progress / result function to retrieve
     information about the task status
 
     Args:
         data_list:
+        xslt_id:
         target_template_id:
         migrate: (boolean) Perform the migration
         user:
@@ -302,19 +289,20 @@ def migrate_data_list(data_list, target_template_id, migrate, user):
         Async task id
     """
     task = async_migration_task.delay(
-        data_list, str(target_template_id), user.id, migrate
+        data_list, xslt_id, str(target_template_id), user.id, migrate
     )
     return task.task_id
 
 
 @access_control(has_perm_administration)
-def migrate_template_list(template_id_list, target_template_id, migrate, user):
+def migrate_template_list(template_id_list, xslt_id, target_template_id, migrate, user):
     """Perform a migration / validation of all the data which belong to the given template id list
     NB: This action is executed with an async task, use the progress / result function to retrieve
     information about the task status
 
     Args:
         template_id_list:
+        xslt_id:
         target_template_id:
         migrate: (boolean) Perform the migration
         user:
@@ -323,6 +311,6 @@ def migrate_template_list(template_id_list, target_template_id, migrate, user):
         Async task id
     """
     task = async_template_migration_task.delay(
-        template_id_list, str(target_template_id), user.id, migrate
+        template_id_list, xslt_id, str(target_template_id), user.id, migrate
     )
     return task.task_id
