@@ -2,14 +2,15 @@
 """
 
 from django_mongoengine import fields
-from mongoengine.queryset.visitor import Q
 from mongoengine import errors as mongoengine_errors
 from mongoengine.queryset.base import NULLIFY
+from mongoengine.queryset.visitor import Q
 
 from core_main_app.commons import exceptions
 from core_main_app.components.abstract_data.models import AbstractData
 from core_main_app.components.template.models import Template
 from core_main_app.components.workspace.models import Workspace
+from core_main_app.utils.query.mongo.prepare import sanitize
 
 
 # TODO: Create publication workflow manager
@@ -122,6 +123,7 @@ class Data(AbstractData):
         Returns:
 
         """
+        sanitize(query)
         return Data.objects(__raw__=query).order_by(*order_by_field)
 
     @staticmethod
