@@ -6,19 +6,18 @@ from celery import shared_task
 from celery.result import AsyncResult
 
 from core_main_app.components.data import api as data_api
-from core_main_app.components.template import api as template_api
+from core_main_app.components.xsl_transformation import api as xsl_transformation_api
 from core_main_app.components.user import api as user_api
-from core_main_app.utils.pagination.mongoengine_paginator.paginator import (
-    MongoenginePaginator,
-)
+from core_main_app.system import api as system_api
 
 
 @shared_task
-def async_migration_task(data_list, template_id, user_id, migrate):
+def async_migration_task(data_list, xslt_id, template_id, user_id, migrate):
     """Async task which perform a migration / validation of the data list for the given target template id
 
     Args:
         data_list:
+        xslt_id:
         template_id:
         user_id:
         migrate: (boolean) Perform the migration
@@ -32,18 +31,28 @@ def async_migration_task(data_list, template_id, user_id, migrate):
     total_data = len(data_list)
 
     try:
-        target_template = template_api.get(template_id)
         user = user_api.get_user_by_id(user_id)
+        target_template = system_api.get_template_by_id(template_id)
+
+        # get xsl transformation if selected
+        if xslt_id is not None:
+            xslt = xsl_transformation_api.get_by_id(str(xslt_id))
 
         for data_id in data_list:
             data = data_api.get_by_id(data_id, user=user)
             # modify the data temporarily with the new targeted template
             data.template = target_template
 
+            if xslt_id is not None:
+                # modify the xml content temporarily with the transformed data content
+                data.xml_content = xsl_transformation_api.xsl_transform(
+                    data.xml_content, xslt.name
+                )
+
             try:
                 # save the new template for the data if the migration is True
                 if migrate:
-                    data_api.upsert(data, user)
+                    system_api.upsert_data(data)
                 else:
                     # check if the data is valid
                     data_api.check_xml_file_is_valid(data)
@@ -68,11 +77,14 @@ def async_migration_task(data_list, template_id, user_id, migrate):
 
 
 @shared_task
-def async_template_migration_task(templates, target_template_id, user_id, migrate):
+def async_template_migration_task(
+    templates, xslt_id, target_template_id, user_id, migrate
+):
     """Async task which perform a migration / validation of all the data which belong to the given template id list
 
     Args:
         templates:
+        xslt_id:
         target_template_id:
         user_id
         migrate: (boolean) Perform the migration
@@ -92,7 +104,10 @@ def async_template_migration_task(templates, target_template_id, user_id, migrat
             # get the user
             user = user_api.get_user_by_id(user_id)
             # get the target template
-            target_template = template_api.get(target_template_id)
+            target_template = system_api.get_template_by_id(target_template_id)
+            # get xsl transformation if selected
+            if xslt_id is not None:
+                xslt = xsl_transformation_api.get_by_id(str(xslt_id))
 
             for template_id in templates:
 
@@ -118,11 +133,18 @@ def async_template_migration_task(templates, target_template_id, user_id, migrat
 
                     # modify the data temporarily with the new targeted template
                     data.template = target_template
+
+                    if xslt_id is not None:
+                        # modify the xml content temporarily with the transformed data content
+                        data.xml_content = xsl_transformation_api.xsl_transform(
+                            data.xml_content, xslt.name
+                        )
+
                     # check if the data is valid
                     try:
                         # save the new template for the data if the migration is True
                         if migrate:
-                            data_api.upsert(data, user)
+                            system_api.upsert_data(data)
                         else:
                             data_api.check_xml_file_is_valid(data)
 
