@@ -3,7 +3,15 @@ Template API
 """
 import logging
 
+from core_main_app.access_control.api import is_superuser
+from core_main_app.access_control.decorators import access_control
 from core_main_app.commons import exceptions
+from core_main_app.components.template.access_control import (
+    can_read,
+    can_write,
+    get_accessible_owners,
+    can_read_list,
+)
 from core_main_app.components.template.models import Template
 from core_main_app.utils.xml import (
     is_schema_valid,
@@ -15,31 +23,35 @@ from core_main_app.utils.xml import (
 logger = logging.getLogger(__name__)
 
 
-def upsert(template):
+@access_control(can_write)
+def upsert(template, request):
     """Save or Updates the template.
 
     Args:
         template:
+        request:
 
     Returns:
 
     """
     # Check if schema is valid
-    is_schema_valid(template.content)
+    is_schema_valid(template.content, request=request)
     # Get hash for the template
     template.hash = get_hash(template.content)
     # Register local dependencies
-    _register_local_dependencies(template)
+    _register_local_dependencies(template, request=request)
     # Save template
     return template.save()
 
 
-def init_template_with_dependencies(template, dependencies_dict):
+@access_control(can_write)
+def init_template_with_dependencies(template, dependencies_dict, request):
     """Initialize template content and dependencies from a dictionary.
 
     Args:
         template:
         dependencies_dict:
+        request:
 
     Returns:
 
@@ -47,18 +59,20 @@ def init_template_with_dependencies(template, dependencies_dict):
     if dependencies_dict is not None:
         # update template content
         template.content = get_template_with_server_dependencies(
-            template.content, dependencies_dict
+            template.content, dependencies_dict, request=request
         )
 
     return template
 
 
-def set_display_name(template, display_name):
+@access_control(can_write)
+def set_display_name(template, display_name, request):
     """Set template display name.
 
     Args:
         template:
         display_name:
+        request:
 
     Returns:
 
@@ -69,11 +83,13 @@ def set_display_name(template, display_name):
     template.save()
 
 
-def get(template_id):
+@access_control(can_read)
+def get(template_id, request):
     """Get a template.
 
     Args:
         template_id:
+        request:
 
     Returns:
 
@@ -81,54 +97,68 @@ def get(template_id):
     return Template.get_by_id(template_id)
 
 
-def get_all_by_hash(template_hash):
+@access_control(can_read_list)
+def get_all_accessible_by_hash(template_hash, request):
     """Return all template having the given hash.
 
     Args:
-        template_hash: Template hash.
+        template_hash: Template hash
+        request:
 
     Returns:
         List of Template instance.
 
     """
-    return Template.get_all_by_hash(template_hash)
+    return Template.get_all_by_hash(
+        template_hash, users=get_accessible_owners(request=request)
+    )
 
 
-def get_all_by_hash_list(template_hash_list):
+@access_control(can_read_list)
+def get_all_accessible_by_hash_list(template_hash_list, request):
     """Return all template having the given hash list.
 
     Args:
         template_hash_list: Template hash list.
+        request:
 
     Returns:
         List of Template instance.
 
     """
-    return Template.get_all_by_hash_list(template_hash_list)
+    return Template.get_all_by_hash_list(
+        template_hash_list, users=get_accessible_owners(request=request)
+    )
 
 
-def get_all_by_id_list(template_id_list):
+@access_control(can_read_list)
+def get_all_accessible_by_id_list(template_id_list, request):
     """Returns all template with id in list
 
     Args:
         template_id_list:
+        request:
 
     Returns:
 
     """
-    return Template.get_all_by_id_list(template_id_list)
+    return Template.get_all_by_id_list(
+        template_id_list, users=get_accessible_owners(request=request)
+    )
 
 
-def get_all(is_cls=True):
+@access_control(can_read_list)
+def get_all(request, is_cls=True):
     """List all templates.
 
     Returns:
 
     """
-    return Template.get_all(is_cls)
+    return Template.get_all(is_cls, users=get_accessible_owners(request=request))
 
 
-def delete(template):
+@access_control(can_write)
+def delete(template, request):
     """Delete the template.
 
     Returns:
@@ -137,7 +167,7 @@ def delete(template):
     template.delete()
 
 
-def _register_local_dependencies(template):
+def _register_local_dependencies(template, request):
     """Register local dependencies for the given template.
 
     Args:
@@ -153,7 +183,7 @@ def _register_local_dependencies(template):
     for local_dependency in local_dependencies:
         try:
             # get the dependency
-            dependency_object = get(local_dependency)
+            dependency_object = get(local_dependency, request=request)
             # add the dependency
             template.dependencies.append(dependency_object)
         except exceptions.DoesNotExist as e:
@@ -162,17 +192,3 @@ def _register_local_dependencies(template):
                     local_dependency, str(e)
                 )
             )
-
-
-def get_all_templates_by_dependencies(dependency_id_list):
-    """List all templates having the given dependencies.
-
-    Args:
-        dependency_id_list: List of dependency ids.
-
-    Returns:
-        List of templates.
-
-    """
-
-    return Template.get_all_templates_by_dependencies(dependency_id_list)
