@@ -13,6 +13,7 @@ class Template(Document):
 
     filename = fields.StringField(validation=not_empty_or_whitespaces)
     content = fields.StringField()
+    user = fields.StringField(blank=True)
     hash = fields.StringField()
     _display_name = fields.StringField(blank=True)
     dependencies = fields.ListField(
@@ -22,18 +23,25 @@ class Template(Document):
     meta = {"allow_inheritance": True}
 
     @staticmethod
-    def get_all(is_cls):
+    def get_all(is_cls, users=None):
         """Return all templates.
 
-        Returns:
+        Args:
+            is_cls (bool): True if filtering by templates only.
+            users (list|None): List of users having access to the template.
 
+        Returns:
+            list<Template> - List of template following the query parameters.
         """
-        if is_cls:
-            # will return all Template object only
-            return Template.objects(_cls=Template.__name__).all()
-        else:
-            # will return all inherited object
-            return Template.object().all()
+        template_query_kwargs = dict()
+
+        if is_cls:  # will return all Template object only
+            template_query_kwargs["_cls"] = Template.__name__
+
+        if users is not None:  # select specific user if it is defined
+            template_query_kwargs["user__in"] = users
+
+        return Template.objects(**template_query_kwargs).all()
 
     @staticmethod
     def get_by_id(template_id):
@@ -53,56 +61,51 @@ class Template(Document):
             raise exceptions.ModelError(str(e))
 
     @staticmethod
-    def get_all_by_hash(template_hash):
+    def get_all_by_hash(template_hash, users):
         """Return all template having the given hash.
 
         Args:
             template_hash: Template hash.
+            users:
 
         Returns:
             List of Template instance.
 
         """
+        if users is not None:
+            return Template.objects(hash=template_hash, user__in=users).all()
         return Template.objects(hash=template_hash).all()
 
     @staticmethod
-    def get_all_by_hash_list(template_hash_list):
+    def get_all_by_hash_list(template_hash_list, users):
         """Return all template having the given hash list.
 
         Args:
             template_hash_list: Template hash list.
+            users:
 
         Returns:
             List of Template instance.
 
         """
+        if users is not None:
+            return Template.objects(hash__in=template_hash_list, user__in=users).all()
         return Template.objects(hash__in=template_hash_list).all()
 
     @staticmethod
-    def get_all_by_id_list(template_id_list):
+    def get_all_by_id_list(template_id_list, users=None):
         """Return all template with id in list.
 
         Args:
             template_id_list:
+            users:
 
         Returns:
 
         """
-        return Template.objects(pk__in=template_id_list)
-
-    @staticmethod
-    def get_all_templates_by_dependencies(dependency_id_list):
-        """List all templates having the given dependencies.
-
-        Args:
-            dependency_id_list: List of dependency ids.
-
-        Returns:
-            List of templates.
-
-        """
-
-        return Template.objects(dependencies__in=dependency_id_list).all()
+        if users is not None:
+            return Template.objects(pk__in=template_id_list, user__in=users).all()
+        return Template.objects(pk__in=template_id_list).all()
 
     @property
     def display_name(self):
