@@ -1,51 +1,62 @@
 """
 Template Version Manager API
 """
+from core_main_app.access_control.api import is_superuser
+from core_main_app.access_control.decorators import access_control
 from core_main_app.components.template import api as template_api
+from core_main_app.components.template.access_control import can_read, can_read_global
+from core_main_app.components.template_version_manager.access_control import can_write
 from core_main_app.components.template_version_manager.models import (
     TemplateVersionManager,
 )
 from core_main_app.components.version_manager import api as version_manager_api
+from core_main_app.components.version_manager.access_control import can_read_list
 from core_main_app.components.version_manager.utils import (
     get_latest_version_name,
     get_version_name,
 )
 
 
-def insert(template_version_manager, template):
+@access_control(can_write)
+def insert(template_version_manager, template, request):
     """Add a version to a template version manager.
 
     Args:
         template_version_manager:
         template:
+        request:
 
     Returns:
 
     """
     # save the template in database
-    template_api.upsert(template)
+    template_api.upsert(template, request=request)
     try:
         # insert the initial template in the version manager
-        version_manager_api.insert_version(template_version_manager, template)
+        version_manager_api.insert_version(
+            template_version_manager, template, request=request
+        )
         # insert the version manager in database
-        version_manager_api.upsert(template_version_manager)
+        version_manager_api.upsert(template_version_manager, request=request)
         # get template display name
         display_name = get_latest_version_name(template_version_manager)
         # update saved template
-        template_api.set_display_name(template, display_name)
+        template_api.set_display_name(template, display_name, request=request)
         # return version manager
         return template_version_manager
     except Exception as e:
-        template_api.delete(template)
+        template_api.delete(template, request=request)
         raise e
 
 
-def edit_title(template_version_manager, title):
+@access_control(can_write)
+def edit_title(template_version_manager, title, request):
     """Edit template version manager title.
 
     Args:
         template_version_manager:
         title:
+        request:
 
     Returns:
 
@@ -55,14 +66,15 @@ def edit_title(template_version_manager, title):
     # save template version manager
     template_version_manager.save_template_version_manager()
     # update templates display names
-    update_templates_display_name(template_version_manager)
+    _update_templates_display_name(template_version_manager, request=request)
 
 
-def update_templates_display_name(template_version_manager):
+def _update_templates_display_name(template_version_manager, request):
     """Update templates display name.
 
     Args:
         template_version_manager:
+        request:
 
     Returns:
 
@@ -72,89 +84,60 @@ def update_templates_display_name(template_version_manager):
         # get template id from list of versions
         template_id = template_version_manager.versions[i]
         # get template from template id
-        template = template_api.get(template_id)
+        template = template_api.get(template_id, request=request)
         # get display name for the template
         display_name = get_version_name(template_version_manager.title, i + 1)
         # update template's display name
-        template_api.set_display_name(template, display_name)
+        template_api.set_display_name(template, display_name, request=request)
 
 
-def get_by_id(template_version_manager_id):
-    """Get a template version manager by its id.
-
-    Args:
-        template_version_manager_id: Id.
-
-    Returns:
-
-    """
-    return TemplateVersionManager.get_by_id(template_version_manager_id)
-
-
-def get_global_version_managers(_cls=True):
+@access_control(can_read_global)
+def get_global_version_managers(request, _cls=True):
     """Get all global version managers of a template.
 
-    Returns:
+    Args:
+        request:
         _cls:
+
+    Returns:
+
     """
     return TemplateVersionManager.get_global_version_managers(_cls)
 
 
-def get_active_global_version_manager(_cls=True):
+@access_control(can_read_global)
+def get_active_global_version_manager(request, _cls=True):
     """Return all active Version Managers with user set to None.
 
+    Args:
+        request:
+        _cls:
+
     Returns:
 
     """
     return TemplateVersionManager.get_active_global_version_manager(_cls)
 
 
-def get_disable_global_version_manager(_cls=True):
-    """Return all disabled Version Managers with user set to None.
-
-    Returns:
-
-    """
-    return TemplateVersionManager.get_disable_global_version_manager(_cls)
-
-
-def get_active_version_manager_by_user_id(user_id, _cls=True):
+# NOTE: access control, filter by user in request
+def get_active_version_manager_by_user_id(request, _cls=True):
     """Return all active Version Managers with given user id.
 
     Returns:
 
     """
-    return TemplateVersionManager.get_active_version_manager_by_user_id(user_id, _cls)
+    return TemplateVersionManager.get_active_version_manager_by_user_id(
+        str(request.user.id), _cls
+    )
 
 
-def get_disable_version_manager_by_user_id(user_id, _cls=True):
-    """Return all disabled Version Managers with given user id.
-
-    Returns:
-
-    """
-    return TemplateVersionManager.get_disable_version_manager_by_user_id(user_id, _cls)
-
-
-def get_version_number(template_version_manager, template):
-    """Return version number from version id.
-
-    Args:
-        template_version_manager:
-        template:
-
-    Returns:
-        Version number
-
-    """
-    return template_version_manager.get_version_number(template)
-
-
-def get_by_version_id(version_id):
+@access_control(can_read)
+def get_by_version_id(version_id, request):
     """Get the template version manager containing the given version id.
 
     Args:
         version_id: version id.
+        request:
 
     Returns:
         template version manager.
@@ -163,11 +146,13 @@ def get_by_version_id(version_id):
     return TemplateVersionManager.get_by_version_id(version_id)
 
 
-def get_all_by_version_ids(version_ids):
+@access_control(can_read_list)
+def get_all_by_version_ids(version_ids, request):
     """Get all template version managers by a list of version ids.
 
     Args:
-        version_ids: list of version ids.
+        version_ids: list of version ids:
+        request:
 
     Returns:
         List of template version managers.
@@ -176,25 +161,20 @@ def get_all_by_version_ids(version_ids):
     return TemplateVersionManager.get_all_by_version_ids(version_ids)
 
 
-def get_all_version_manager_except_user_id(user_id, _cls=True):
-    """Return all  Version Managers of all users except user with given user id.
-
-    Returns:
-
-    """
-    return TemplateVersionManager.get_all_version_manager_except_user_id(user_id, _cls)
-
-
-def get_all_by_user_id(user_id, _cls=True):
+# NOTE: access control, filter by user in request
+def get_all_by_user_id(request, _cls=True):
     """Return all Template Version Managers with given user id.
 
     Returns:
 
     """
-    return TemplateVersionManager.get_all_version_manager_by_user_id(user_id, _cls)
+    return TemplateVersionManager.get_all_version_manager_by_user_id(
+        str(request.user.id), _cls
+    )
 
 
-def get_all(_cls=True):
+@access_control(is_superuser)
+def get_all(request, _cls=True):
     """Return all Template Version Managers.
 
     Returns:
