@@ -41,20 +41,6 @@ class TemplateVersionManager(VersionManager):
             queryset = queryset.filter(_cls=TemplateVersionManager.class_name).all()
         return queryset
 
-    @staticmethod
-    def get_disable_global_version_manager(_cls=True):
-        """Return all disabled Version Managers with user set to None.
-
-        Returns:
-
-        """
-        queryset = super(
-            TemplateVersionManager, TemplateVersionManager
-        ).get_disable_global_version_manager()
-        if _cls:
-            queryset = queryset.filter(_cls=TemplateVersionManager.class_name).all()
-        return queryset
-
     @staticmethod
     def get_active_version_manager_by_user_id(user_id, _cls=True):
         """Return all active Version Managers with given user id.
@@ -62,6 +48,8 @@ class TemplateVersionManager(VersionManager):
         Returns:
 
         """
+        if not user_id:
+            return TemplateVersionManager.objects.none()
         queryset = super(
             TemplateVersionManager, TemplateVersionManager
         ).get_active_version_manager_by_user_id(user_id)
@@ -69,20 +57,6 @@ class TemplateVersionManager(VersionManager):
             queryset = queryset.filter(_cls=TemplateVersionManager.class_name).all()
         return queryset
 
-    @staticmethod
-    def get_disable_version_manager_by_user_id(user_id, _cls=True):
-        """Return all disabled Version Managers with given user id.
-
-        Returns:
-
-        """
-        queryset = super(
-            TemplateVersionManager, TemplateVersionManager
-        ).get_disable_version_manager_by_user_id(user_id)
-        if _cls:
-            queryset = queryset.filter(_cls=TemplateVersionManager.class_name).all()
-        return queryset
-
     @staticmethod
     def get_by_version_id(version_id):
         """Get the template version manager containing the given version id.
@@ -143,6 +117,8 @@ class TemplateVersionManager(VersionManager):
         Returns:
 
         """
+        if not user_id:
+            return TemplateVersionManager.objects.none()
         queryset = super(
             TemplateVersionManager, TemplateVersionManager
         ).get_all_version_manager_by_user_id(user_id)
