@@ -237,24 +237,8 @@ def get_by_template_hash(template_hash):
         The TemplateXslRendering instance.
 
     """
-    instance = None
-    # Get list of templates with the given hash
-    templates = template_api.get_all_by_hash(template_hash)
-    # Check if one of the templates has a xslt. Stop when found.
     # FIXME: Check if this process is okay (no solutions to distinguish templates from same hash)
-    for template in templates:
-        try:
-            instance = TemplateXslRendering.get_by_template_id(template.id)
-            break
-        except exceptions.DoesNotExist as e:
-            logger.warning("get_by_template_hash threw an exception: ".format(str(e)))
-
-    if instance is None:
-        raise exceptions.DoesNotExist(
-            "No TemplateXslRendering found with the given template hash"
-        )
-
-    return instance
+    return TemplateXslRendering.get_by_template_hash(template_hash)
 
 
 def get_all():
