@@ -22,30 +22,27 @@ class AbstractExecuteLocalQueryView(APIView, metaclass=ABCMeta):
         Parameters:
 
             # get all results (paginated)
-            {"query": "{}"}
+            {"query": {}}
             # get all results
-            {"query": "{}", "all": "true"}
+            {"query": {}, "all": "true"}
             # get all results filtered by title
-            {"query": "{}", "title": "title_string"}
-            # get all results filtered by workspaces
-            {"query": "{}", "workspaces": [{"id":"[workspace_id]"}]}
+            {"query": {}, "title": "title_string"}
+             # get all results filtered by workspaces
+            {"query": {}, "workspaces": [{"id":"[workspace_id]"}]}
             # get all results filtered by private workspace
-            {"query": "{}", "workspaces": [{"id":"None"}]}
+            {"query": {}, "workspaces": [{"id":"None"}]}
             # get all results filtered by templates
-            {"query": "{}", "templates": [{"id":"[template_id]"}] }
+            {"query": {}, "templates": [{"id":"[template_id]"}] }
             # get all results that verify a given criteria
-            {"query": "{\\"root.element.value\\": 2}"}
+            {"query": {"root.element.value": 2}}
+            # get values at xpath
+            {"query": {}, "xpath": "/ns:root/@element", "namespaces": {"ns": "<namespace_url>"}}
             # get results using multiple options
-            {"query": "{\\"root.element.value\\": 2}", "workspaces": [{"id":"workspace_id"}] , "all": "true"}
-            {"query": "{\\"root.element.value\\": 2}", "templates": [{"id":"template_id"}] , "all": "true"}
-            {"query": "{\\"root.element.value\\": 2}", "templates": [{"id":"template_id"}],
+            {"query": {"root.element.value": 2}, "workspaces": [{"id":"workspace_id"}] , "all": "true"}
+            {"query": {"root.element.value": 2}, "templates": [{"id":"template_id"}] , "all": "true"}
+            {"query": {"root.element.value": 2}, "templates": [{"id":"template_id"}],
             "workspaces": [{"id":"[workspace_id]"}] ,"all": "true"}
 
-
-        Warning:
-
-            Need to backslash double quotes in JSON payload
-
         Args:
 
             request: HTTP request
@@ -66,11 +63,7 @@ class AbstractExecuteLocalQueryView(APIView, metaclass=ABCMeta):
 
         Parameters:
 
-            {"query": "{\"$or\": [{\"image.owner\": \"Peter\"}, {\"image.owner.#text\":\"Peter\"}]}"}
-
-        Warning:
-
-            Need to backslash double quotes in JSON payload
+            {"query": {"$or": [{"image.owner": "Peter"}, {"image.owner.#text":"Peter"}]}}
 
         Args:
             request:
@@ -200,7 +193,9 @@ class AbstractMigrationView(APIView, metaclass=ABCMeta):
                     "data_id1",
                     "data_id2",
                     "data_id3"
-                ]
+                ],
+                "xslt": "xslt_id"
+
             }
 
         Args:
@@ -220,18 +215,19 @@ class AbstractMigrationView(APIView, metaclass=ABCMeta):
               content: Internal server error
         """
         try:
+            xslt_id = request.data["xslt"] if "xslt" in request.data else None
             if template_id and "data" in request.data:
                 data_list = request.data["data"]
                 # launch the migration task
                 task_id = data_api.migrate_data_list(
-                    data_list, template_id, migrate, request.user
+                    data_list, xslt_id, template_id, migrate, request.user
                 )
                 return Response(task_id, status=status.HTTP_200_OK)
             elif template_id and "template" in request.data:
                 data_list = request.data["template"]
                 # launch the migration task
                 task_id = data_api.migrate_template_list(
-                    data_list, template_id, migrate, request.user
+                    data_list, xslt_id, template_id, migrate, request.user
                 )
                 return Response(task_id, status=status.HTTP_200_OK)
             else:
