@@ -6,6 +6,7 @@ from rest_framework_mongoengine.serializers import DocumentSerializer
 
 import core_main_app.components.data.api as data_api
 from core_main_app.components.data.models import Data
+from core_main_app.components.template import api as template_api
 
 
 class XMLContentField(serializers.Field):
@@ -39,12 +40,16 @@ class DataSerializer(DocumentSerializer):
             "user_id",
             "title",
             "xml_content",
+            "creation_date",
             "last_modification_date",
+            "last_change_date",
         ]
         read_only_fields = (
             "id",
             "user_id",
+            "creation_date",
             "last_modification_date",
+            "last_change_date",
         )
 
     def create(self, validated_data):
@@ -58,13 +63,16 @@ class DataSerializer(DocumentSerializer):
             if "workspace" in validated_data
             else None,
             title=validated_data["title"],
-            user_id=str(validated_data["user"].id),
+            user_id=str(self.context["request"].user.id),
         )
+        # Get template
+        template_api.get(instance.template.id, request=self.context["request"])
+
         # Set xml content
         instance.xml_content = validated_data["xml_content"]
 
         # Save the data and retrieve the inserted object
-        inserted_data = data_api.upsert(instance, validated_data["user"])
+        inserted_data = data_api.upsert(instance, self.context["request"])
 
         # Encode the response body
         inserted_data.xml_content = inserted_data.xml_content.encode("utf-8")
@@ -77,7 +85,7 @@ class DataSerializer(DocumentSerializer):
         """
         instance.title = validated_data.get("title", instance.title)
         instance.xml_content = validated_data.get("xml_content", instance.xml_content)
-        return data_api.upsert(instance, validated_data["user"])
+        return data_api.upsert(instance, self.context["request"])
 
 
 # FIXME: Should use in the future an serializer with dynamic fields (init depth with parameter for example)
@@ -95,5 +103,7 @@ class DataWithTemplateInfoSerializer(DocumentSerializer):
             "user_id",
             "title",
             "xml_content",
+            "creation_date",
             "last_modification_date",
+            "last_change_date",
         ]
