@@ -2,12 +2,6 @@
 """
 import json
 
-from bson import ObjectId
-
-from core_main_app.settings import RESULTS_PER_PAGE
-from core_main_app.utils.pagination.mongoengine_paginator.paginator import (
-    MongoenginePaginator,
-)
 from django.http import Http404
 from rest_framework import status
 from rest_framework.decorators import api_view
@@ -24,22 +18,24 @@ from core_main_app.access_control.api import check_can_write
 from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons import exceptions
 from core_main_app.components.data import api as data_api
+from core_main_app.components.data.tasks import get_task_progress, get_task_result
 from core_main_app.components.user import api as user_api
 from core_main_app.components.workspace import api as workspace_api
 from core_main_app.rest.data.abstract_views import AbstractExecuteLocalQueryView
+from core_main_app.rest.data.abstract_views import AbstractMigrationView
 from core_main_app.rest.data.admin_serializers import AdminDataSerializer
 from core_main_app.rest.data.serializers import (
     DataSerializer,
     DataWithTemplateInfoSerializer,
 )
-from core_main_app.rest.data.abstract_views import AbstractMigrationView
 from core_main_app.utils.boolean import to_bool
 from core_main_app.utils.databases.pymongo_database import get_full_text_query
 from core_main_app.utils.file import get_file_http_response
-from core_main_app.components.data.tasks import get_task_progress, get_task_result
 from core_main_app.utils.pagination.rest_framework_paginator.pagination import (
     StandardResultsSetPagination,
 )
+from core_main_app.commons.exceptions import XMLError
+from core_main_app.utils.xml import get_content_by_xpath, format_content_xml
 
 
 class DataList(APIView):
@@ -131,12 +127,14 @@ class DataList(APIView):
         """
         try:
             # Build serializer
-            data_serializer = self.serializer(data=request.data)
+            data_serializer = self.serializer(
+                data=request.data, context={"request": request}
+            )
 
             # Validate data
             data_serializer.is_valid(True)
             # Save data
-            data_serializer.save(user=request.user)
+            data_serializer.save()
 
             # Return the serialized data
             return Response(data_serializer.data, status=status.HTTP_201_CREATED)
@@ -277,6 +275,9 @@ class DataDetail(APIView):
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
+        except AccessControlError as e:
+            content = {"message": str(e)}
+            return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
@@ -310,6 +311,9 @@ class DataDetail(APIView):
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
+        except AccessControlError as e:
+            content = {"message": str(e)}
+            return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
@@ -346,13 +350,16 @@ class DataDetail(APIView):
 
             # Build serializer
             data_serializer = self.serializer(
-                instance=data_object, data=request.data, partial=True
+                instance=data_object,
+                data=request.data,
+                partial=True,
+                context={"request": request},
             )
 
             # Validate data
             data_serializer.is_valid(True)
             # Save data
-            data_serializer.save(user=request.user)
+            data_serializer.save()
 
             return Response(data_serializer.data, status=status.HTTP_200_OK)
         except ValidationError as validation_exception:
@@ -361,6 +368,9 @@ class DataDetail(APIView):
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
+        except AccessControlError as e:
+            content = {"message": str(e)}
+            return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
@@ -472,6 +482,11 @@ class DataDownload(APIView):
             request: HTTP request
             pk: ObjectId
 
+        Examples:
+
+            ../data/download/[data_id]
+            ../data/download/[data_id]?pretty_print=true
+
         Returns:
 
             - code: 200
@@ -485,12 +500,25 @@ class DataDownload(APIView):
             # Get object
             data_object = self.get_object(request, pk)
 
+            # get xml content
+            xml_content = data_object.xml_content
+
+            # get format bool
+            format = request.query_params.get("pretty_print", False)
+
+            # format content
+            if to_bool(format):
+                xml_content = format_content_xml(xml_content)
+
             return get_file_http_response(
-                data_object.xml_content, data_object.title, "text/xml", "xml"
+                xml_content, data_object.title, "text/xml", "xml"
             )
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
+        except XMLError:
+            content = {"message": "Content is not well formatted XML."}
+            return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
             return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
@@ -562,29 +590,27 @@ class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
         Parameters:
 
             # get all results (paginated)
-            {"query": "{}"}
+            {"query": {}}
             # get all results
-            {"query": "{}", "all": "true"}
+            {"query": {}, "all": "true"}
             # get all results filtered by title
-            {"query": "{}", "title": "title_string"}
+            {"query": {}, "title": "title_string"}
              # get all results filtered by workspaces
-            {"query": "{}", "workspaces": [{"id":"[workspace_id]"}]}
+            {"query": {}, "workspaces": [{"id":"[workspace_id]"}]}
             # get all results filtered by private workspace
-            {"query": "{}", "workspaces": [{"id":"None"}]}
+            {"query": {}, "workspaces": [{"id":"None"}]}
             # get all results filtered by templates
-            {"query": "{}", "templates": [{"id":"[template_id]"}] }
+            {"query": {}, "templates": [{"id":"[template_id]"}] }
             # get all results that verify a given criteria
-            {"query": "{\\"root.element.value\\": 2}"}
+            {"query": {"root.element.value": 2}}
+            # get values at xpath
+            {"query": {}, "xpath": "/ns:root/@element", "namespaces": {"ns": "<namespace_url>"}}
             # get results using multiple options
-            {"query": "{\\"root.element.value\\": 2}", "workspaces": [{"id":"workspace_id"}] , "all": "true"}
-            {"query": "{\\"root.element.value\\": 2}", "templates": [{"id":"template_id"}] , "all": "true"}
-            {"query": "{\\"root.element.value\\": 2}", "templates": [{"id":"template_id"}],
+            {"query": {"root.element.value": 2}, "workspaces": [{"id":"workspace_id"}] , "all": "true"}
+            {"query": {"root.element.value": 2}, "templates": [{"id":"template_id"}] , "all": "true"}
+            {"query": {"root.element.value": 2}, "templates": [{"id":"template_id"}],
             "workspaces": [{"id":"[workspace_id]"}] ,"all": "true"}
 
-        Warning:
-
-            Need to backslash double quotes in JSON payload
-
         Examples:
 
             ../data/query/
@@ -616,7 +642,15 @@ class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
 
             The response paginated
         """
+        xpath = self.request.data.get("xpath", None)
+        namespaces = self.request.data.get("namespaces", None)
         if "all" in self.request.data and to_bool(self.request.data["all"]):
+            # Select values at xpath if provided
+            if xpath:
+                for data_object in data_list:
+                    data_object.xml_content = get_content_by_xpath(
+                        data_object.xml_content, xpath, namespaces=namespaces
+                    )
             # Serialize data list
             data_serializer = self.serializer(data_list, many=True)
             # Return response
@@ -628,6 +662,13 @@ class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
             # Get requested page from list of results
             page = paginator.paginate_queryset(data_list, self.request)
 
+            # Select values at xpath if provided
+            if xpath:
+                for data_object in page:
+                    data_object.xml_content = get_content_by_xpath(
+                        data_object.xml_content, xpath, namespaces=namespaces
+                    )
+
             # Serialize page
             data_serializer = self.serializer(page, many=True)
 
@@ -787,6 +828,14 @@ class DataPermissions(APIView):
     Get the permissions of the data according to the client user
     """
 
+    def get(self, request):
+        """GET requests"""
+        return self.process_request(request)
+
+    def post(self, request):
+        """POST requests"""
+        return self.process_request(request)
+
     def get_object(self, request, pk):
         """Get data from db
 
@@ -804,7 +853,7 @@ class DataPermissions(APIView):
         except exceptions.DoesNotExist:
             raise Http404
 
-    def get(self, request):
+    def process_request(self, request):
         """Give the user permissions for a list of data ids
 
         Parameters:
