@@ -37,7 +37,9 @@ class GlobalTemplateVersionManagerList(AbstractTemplateVersionManagerList):
 
             List of GlobalTemplateVersionManager
         """
-        return template_version_manager_api.get_global_version_managers()
+        return template_version_manager_api.get_global_version_managers(
+            request=self.request
+        )
 
 
 class UserTemplateVersionManagerList(AbstractTemplateVersionManagerList):
@@ -52,9 +54,7 @@ class UserTemplateVersionManagerList(AbstractTemplateVersionManagerList):
 
             List of UserTemplateVersionManager
         """
-        return template_version_manager_api.get_all_by_user_id(
-            user_id=str(self.request.user.id)
-        )
+        return template_version_manager_api.get_all_by_user_id(request=self.request)
 
 
 class TemplateVersionManagerDetail(APIView):
@@ -62,19 +62,20 @@ class TemplateVersionManagerDetail(APIView):
 
     permission_classes = (IsAuthenticated,)
 
-    def get_object(self, pk):
+    def get_object(self, pk, request):
         """Get TemplateVersionManager from db
 
         Args:
 
             pk: ObjectId
+            request:
 
         Returns:
 
             TemplateVersionManager
         """
         try:
-            return version_manager_api.get(pk)
+            return version_manager_api.get(pk, request=request)
         except exceptions.DoesNotExist:
             raise Http404
 
@@ -97,7 +98,7 @@ class TemplateVersionManagerDetail(APIView):
         """
         try:
             # Get object
-            template_version_manager_object = self.get_object(pk)
+            template_version_manager_object = self.get_object(pk, request=request)
 
             # Serialize object
             serializer = TemplateVersionManagerSerializer(
@@ -152,14 +153,17 @@ class TemplateVersion(AbstractTemplateVersionManagerDetail):
             template_version_manager_object = self.get_object(pk)
 
             # Build serializers
-            template_serializer = CreateTemplateSerializer(data=request.data)
+            template_serializer = CreateTemplateSerializer(
+                data=request.data, context={"request": request}
+            )
 
             # Validate data
             template_serializer.is_valid(True)
 
             # Save data
             template_serializer.save(
-                template_version_manager=template_version_manager_object
+                template_version_manager=template_version_manager_object,
+                user=template_version_manager_object.user,
             )
 
             return Response(template_serializer.data, status=status.HTTP_201_CREATED)
@@ -279,7 +283,7 @@ class CurrentTemplateVersion(AbstractStatusTemplateVersion):
 
             TemplateVersion
         """
-        return version_manager_api.set_current(template_object)
+        return version_manager_api.set_current(template_object, request=self.request)
 
 
 class DisableTemplateVersion(AbstractStatusTemplateVersion):
@@ -298,7 +302,9 @@ class DisableTemplateVersion(AbstractStatusTemplateVersion):
 
             TemplateVersion
         """
-        return version_manager_api.disable_version(template_object)
+        return version_manager_api.disable_version(
+            template_object, request=self.request
+        )
 
 
 class RestoreTemplateVersion(AbstractStatusTemplateVersion):
@@ -317,7 +323,9 @@ class RestoreTemplateVersion(AbstractStatusTemplateVersion):
 
             TemplateVersion
         """
-        return version_manager_api.restore_version(template_object)
+        return version_manager_api.restore_version(
+            template_object, request=self.request
+        )
 
 
 class DisableTemplateVersionManager(AbstractStatusTemplateVersionManager):
@@ -337,7 +345,9 @@ class DisableTemplateVersionManager(AbstractStatusTemplateVersionManager):
             TemplateVersionManager
         """
         # FIXME: add return?
-        version_manager_api.disable(template_version_manager_object)
+        version_manager_api.disable(
+            template_version_manager_object, request=self.request
+        )
 
 
 class RestoreTemplateVersionManager(AbstractStatusTemplateVersionManager):
@@ -354,4 +364,6 @@ class RestoreTemplateVersionManager(AbstractStatusTemplateVersionManager):
 
         """
         # FIXME: add return?
-        version_manager_api.restore(template_version_manager_object)
+        version_manager_api.restore(
+            template_version_manager_object, request=self.request
+        )
