@@ -7,7 +7,6 @@ import core_main_app.rest.web_page.views as web_page_views
 import core_main_app.rest.xsl_transformation.views as xsl_transformation_views
 from core_main_app.rest.blob import views as blob_views
 from core_main_app.rest.data import views as data_views
-from core_main_app.rest.user import views as user_views
 from core_main_app.rest.template import views as template_views
 from core_main_app.rest.template_version_manager import (
     views as template_version_manager_views,
@@ -15,6 +14,7 @@ from core_main_app.rest.template_version_manager import (
 from core_main_app.rest.template_xsl_rendering import (
     views as template_xsl_rendering_views,
 )
+from core_main_app.rest.user import views as user_views
 from core_main_app.rest.workspace import views as workspace_views
 
 urlpatterns = [
@@ -71,7 +71,7 @@ urlpatterns = [
     re_path(
         r"^template/xsl_rendering/(?P<pk>\w+)/$",
         template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
-        name="core_main_app_rest_template_download",
+        name="core_main_app_rest_template_xsl_rendering",
     ),
     re_path(
         r"^template/global/$",
@@ -304,24 +304,26 @@ urlpatterns = [
         workspace_views.remove_group_write_right_to_workspace,
         name="core_main_app_rest_workspace_remove_group_write",
     ),
-    re_path(
-        r"^user/(?P<pk>[\w-]+)/$",
-        user_views.UserDetail.as_view(),
-        name="core_main_app_user_detail",
-    ),
     re_path(
         r"^workspace/(?P<workspace_id>\w+)/data/$",
         data_views.DataListByWorkspace.as_view(),
         name="core_main_app_rest_data_workspace_list",
     ),
+    re_path(
+        r"^user/$",
+        user_views.UserListCreateView.as_view(),
+        name="core_main_app_user_list_create",
+    ),
+    re_path(
+        r"^user/(?P<pk>[\w-]+)/$",
+        user_views.UserRetrieveUpdateView.as_view(),
+        name="core_main_app_user_retrieve_update",
+    ),
     re_path(
         r"^blob/(?P<pk>\w+)/change-owner/(?P<user_id>\w+)$",
         blob_views.BlobChangeOwner.as_view(),
         name="core_main_app_rest_blob_change_owner",
     ),
-    re_path(
-        r"^user/$", user_views.UserList.as_view(), name="core_main_app_user_detail"
-    ),
     re_path(
         r"^template/xsl_rendering/(?P<pk>\w+)/set_default_xslt/(?P<xslt_id>\w+)/$",
         template_xsl_rendering_views.TemplateXslRenderingSetDefaultDetailXslt.as_view(),
