@@ -4,6 +4,7 @@ import re
 
 from django import template
 
+from core_main_app import settings
 from core_main_app.utils.urls import get_blob_download_regex
 
 register = template.Library()
@@ -21,11 +22,20 @@ def render_blob_links_in_span(*args, **kwargs):
 
     """
     xml_string = kwargs["xml_string"]
-    # get all blobs link
-    url_blobs = re.findall(get_blob_download_regex(), xml_string)
-    # we attend to frame then with a specific class selector
+
+    # Retrieve blob links using the default download URL
+    url_blobs = get_blob_download_regex(xml_string)
+
+    # Retrieve blob links using PID if the app is installed
+    if "core_linked_records_app" in settings.INSTALLED_APPS:
+        from core_linked_records_app.utils import blob as pid_blob_utils
+
+        url_blobs += pid_blob_utils.get_blob_download_regex(xml_string)
+
+    # Apply special template for the blob urls found
     blob_html_pattern = "<span class='blob-link' data-blob-url=\"{0}\">{0}</span>"
-    # for all urls found, we apply the pattern
+
     for url in url_blobs:
         xml_string = xml_string.replace(url, blob_html_pattern.format(url))
+
     return xml_string
