@@ -37,7 +37,11 @@ def render_xml_as_html(*args, **kwargs):
     template_hash = kwargs.get("template_hash", None)
     xsl_transform_id = kwargs.get("xslt_id", None)
     return _render_xml_as_html(
-        xml_content, template_id, template_hash, XSLType.type_list, xsl_transform_id
+        xml_content,
+        template_id,
+        template_hash,
+        XSLType.type_list,
+        xsl_transform_id,
     )
 
 
@@ -57,7 +61,11 @@ def render_xml_as_html(*args, **kwargs):
     template_hash = kwargs.get("template_hash", None)
     xsl_transform_id = kwargs.get("xslt_id", None)
     return _render_xml_as_html(
-        xml_content, template_id, template_hash, XSLType.type_detail, xsl_transform_id
+        xml_content,
+        template_id,
+        template_hash,
+        XSLType.type_detail,
+        xsl_transform_id,
     )
 
 
