@@ -1,17 +1,17 @@
 """ Url router for the main application
 """
-from django.contrib.auth import views as auth_views
-from django.contrib.auth.decorators import login_required
-from drf_yasg.views import get_schema_view
-from drf_yasg import openapi
 from django.conf.urls import include
+from django.contrib.auth.decorators import login_required
 from django.urls import re_path
+from drf_yasg import openapi
+from drf_yasg.views import get_schema_view
 
 from core_main_app.components.blob import api as blob_api
 from core_main_app.components.data import api as data_api
 from core_main_app.utils.rendering import render
 from core_main_app.views.common import ajax as common_ajax, views as common_views
 from core_main_app.views.user import views as user_views, ajax as user_ajax
+from core_main_app import settings
 
 schema_view = get_schema_view(
     openapi.Info(
@@ -22,8 +22,6 @@ schema_view = get_schema_view(
 
 urlpatterns = [
     re_path(r"^$", user_views.homepage, name="core_main_app_homepage"),
-    re_path(r"^login", user_views.custom_login, name="core_main_app_login"),
-    re_path(r"^logout", user_views.custom_logout, name="core_main_app_logout"),
     re_path(r"^locked", common_views.defender_error_page, name="core_main_app_locked"),
     re_path(r"^rest/", include("core_main_app.rest.urls")),
     re_path(
@@ -36,40 +34,9 @@ urlpatterns = [
     ),
     re_path(
         r"^template/(?P<pk>[\w-]+)/edit/$",
-        login_required(common_ajax.EditTemplateVersionManagerView.as_view()),
+        common_ajax.EditTemplateVersionManagerView.as_view(),
         name="core_main_app_edit_template",
     ),
-    re_path(
-        r"^template/disable",
-        common_ajax.disable_version_manager,
-        name="core_main_app_disable_template",
-    ),
-    re_path(
-        r"^template/restore",
-        common_ajax.restore_version_manager,
-        name="core_main_app_restore_template",
-    ),
-    re_path(
-        r"^template/version/disable",
-        common_ajax.disable_template_version_from_version_manager,
-        name="core_main_app_disable_template_version",
-    ),
-    re_path(
-        r"^template/version/restore",
-        common_ajax.restore_template_version_from_version_manager,
-        name="core_main_app_restore_template_version",
-    ),
-    re_path(
-        r"^template/version/current",
-        common_ajax.set_current_template_version_from_version_manager,
-        name="core_main_app_set_current_template_version",
-    ),
-    re_path(r"^xslt$", common_views.XSLTView.as_view(), name="core_main_app_xslt"),
-    re_path(
-        r"^xslt/upload$",
-        login_required(common_views.UploadXSLTView.as_view()),
-        name="core_main_app_upload_xslt",
-    ),
     re_path(
         r"^template/xslt/(?P<template_id>\w+)",
         login_required(
@@ -83,39 +50,24 @@ urlpatterns = [
     ),
     re_path(
         r"^edit-rights/(?P<workspace_id>\w+)$",
-        login_required(common_views.EditWorkspaceRights.as_view()),
+        common_views.EditWorkspaceRights.as_view(),
         name="core_main_edit_rights_workspace",
     ),
-    re_path(
-        r"^create-workspace",
-        user_ajax.create_workspace,
-        name="core_main_create_workspace",
-    ),
     re_path(
         r"^change-workspace",
-        login_required(user_ajax.LoadFormChangeWorkspace.as_view()),
+        user_ajax.LoadFormChangeWorkspace.as_view(),
         name="core_main_change_workspace",
     ),
     re_path(
         r"^assign-blob-workspace",
-        login_required(user_ajax.AssignView.as_view(api=blob_api)),
+        user_ajax.AssignView.as_view(api=blob_api),
         name="core_main_assign_blob_workspace",
     ),
     re_path(
         r"^assign-data-workspace",
-        login_required(user_ajax.AssignView.as_view(api=data_api)),
+        user_ajax.AssignView.as_view(api=data_api),
         name="core_main_assign_data_workspace",
     ),
-    re_path(
-        r"^public-workspace",
-        user_ajax.set_public_workspace,
-        name="core_main_public_workspace",
-    ),
-    re_path(
-        r"^private-workspace",
-        user_ajax.set_private_workspace,
-        name="core_main_private_workspace",
-    ),
     re_path(
         r"^add-user-form",
         user_ajax.load_add_user_form,
@@ -172,3 +124,27 @@ urlpatterns = [
         name="core_main_add_change_data_display",
     ),
 ]
+
+if settings.ENABLE_SAML2_SSO_AUTH:
+    from djangosaml2 import views as saml2_views
+
+    urlpatterns.append(re_path(r"saml2/", include("djangosaml2.urls")))
+    urlpatterns.append(
+        re_path(
+            r"^saml2/login", saml2_views.LoginView.as_view(), name="core_main_app_login"
+        )
+    )
+    urlpatterns.append(
+        re_path(
+            r"^saml2/logout",
+            saml2_views.LogoutInitView.as_view(),
+            name="core_main_app_logout",
+        )
+    )
+else:
+    urlpatterns.append(
+        re_path(r"^login", user_views.custom_login, name="core_main_app_login")
+    )
+    urlpatterns.append(
+        re_path(r"^logout", user_views.custom_logout, name="core_main_app_logout")
+    )
