@@ -3,11 +3,10 @@
 
 
 class FixtureInterface(object):
-    """ Represent the fixture interface with methods which must be implemented.
-    """
+    """Represent the fixture interface with methods which must be implemented."""
 
     def insert_data(self):
-        """ Insert fixture's data
+        """Insert fixture's data
 
         Returns:
 
