@@ -11,6 +11,12 @@ logger = logging.getLogger(__name__)
 class RequestsResolver(DefaultURIResolver):
     """Requests URI Resolver for lxml"""
 
+    session_id = None
+
+    def __init__(self, session_id=None):
+        super(RequestsResolver, self).__init__()
+        self.session_id = session_id
+
     def resolve(self, url, id, context):
         """Resolve the URI using the requests api
 
@@ -23,7 +29,7 @@ class RequestsResolver(DefaultURIResolver):
 
         """
         try:
-            response = send_get_request(url)
+            response = send_get_request(url, cookies={"sessionid": self.session_id})
             return self.resolve_string(response.content, context)
         except Exception as e:
             # if an error occurs return None to use the next registered resolver (or lxml default resolver)
