@@ -14,19 +14,19 @@ import xml_utils.commons.constants as xml_utils_constants
 import xml_utils.commons.exceptions as xml_utils_exceptions
 import xml_utils.xml_validation.validation as xml_validation
 from core_main_app.commons.exceptions import XMLError
-from core_main_app.settings import XERCES_VALIDATION, SERVER_URI
+from core_main_app.settings import XERCES_VALIDATION, SERVER_URI, XML_POST_PROCESSOR
 from core_main_app.utils.resolvers.resolver_utils import lmxl_uri_resolver
 from core_main_app.utils.urls import get_template_download_pattern
+from xml_utils import xpath as xml_utils_xpath
 from xml_utils.commons.constants import XSL_NAMESPACE
 from xml_utils.xsd_hash import xsd_hash
 from xml_utils.xsd_tree.operations.namespaces import get_namespaces
 from xml_utils.xsd_tree.xsd_tree import XSDTree
-from xml_utils import xpath as xml_utils_xpath
 
 logger = logging.getLogger(__name__)
 
 
-def validate_xml_schema(xsd_tree):
+def validate_xml_schema(xsd_tree, *args, **kwargs):
     """Check if XSD schema is valid, send XSD Schema to server to be validated if
     XERCES_VALIDATION is true.
 
@@ -40,14 +40,18 @@ def validate_xml_schema(xsd_tree):
         try:
             error = xml_validation.xerces_validate_xsd(xsd_tree)
         except Exception:
-            error = xml_validation.lxml_validate_xsd(xsd_tree, lmxl_uri_resolver())
+            error = xml_validation.lxml_validate_xsd(
+                xsd_tree, lmxl_uri_resolver(*args, **kwargs)
+            )
     else:
-        error = xml_validation.lxml_validate_xsd(xsd_tree, lmxl_uri_resolver())
+        error = xml_validation.lxml_validate_xsd(
+            xsd_tree, lmxl_uri_resolver(*args, **kwargs)
+        )
 
     return error
 
 
-def validate_xml_data(xsd_tree, xml_tree):
+def validate_xml_data(xsd_tree, xml_tree, *args, **kwargs):
     """Check if XML data is valid, send XML data to server to be validated if XERCES_VALIDATION is true
 
     Args:
@@ -62,17 +66,17 @@ def validate_xml_data(xsd_tree, xml_tree):
             error = xml_validation.xerces_validate_xml(xsd_tree, xml_tree)
         except Exception:
             error = xml_validation.lxml_validate_xml(
-                xsd_tree, xml_tree, lmxl_uri_resolver()
+                xsd_tree, xml_tree, lmxl_uri_resolver(*args, **kwargs)
             )
     else:
         error = xml_validation.lxml_validate_xml(
-            xsd_tree, xml_tree, lmxl_uri_resolver()
+            xsd_tree, xml_tree, lmxl_uri_resolver(*args, **kwargs)
         )
 
     return error
 
 
-def is_schema_valid(xsd_string):
+def is_schema_valid(xsd_string, *args, **kwargs):
     """Test if the schema is valid to be uploaded.
 
     Args:
@@ -90,7 +94,7 @@ def is_schema_valid(xsd_string):
         errors_str = ", ".join(errors)
         raise exceptions.CoreError(errors_str)
 
-    error = validate_xml_schema(XSDTree.build_tree(xsd_string))
+    error = validate_xml_schema(XSDTree.build_tree(xsd_string), *args, **kwargs)
     if error is not None:
         raise exceptions.XSDError(error)
 
@@ -113,6 +117,23 @@ def is_well_formed_xml(xml_string):
     return True
 
 
+def format_content_xml(xml_string):
+    """Format XML content.
+
+    Args:
+        xml_string:
+
+    Returns:
+
+    """
+
+    try:
+        xml_tree = XSDTree.build_tree(xml_string)
+        return XSDTree.tostring(xml_tree, pretty=True)
+    except Exception:
+        raise exceptions.XMLError("Content is not well formatted XML.")
+
+
 def has_xsl_namespace(xml_string):
     """True if XML has the XSL namespace.
 
@@ -151,19 +172,33 @@ def unparse(json_dict, full_document=True):
     return xmltodict.unparse(preprocessed_dict, full_document=full_document)
 
 
-def raw_xml_to_dict(raw_xml, postprocessor=None):
+def raw_xml_to_dict(raw_xml, postprocessor=None, force_list=None):
     """Transform a raw xml to dict. Returns an empty dict if the parsing failed.
 
     Args:
         raw_xml:
         postprocessor:
+        force_list:
 
     Returns:
 
     """
     try:
-        dict_raw = xmltodict.parse(raw_xml, postprocessor=postprocessor)
-        return dict_raw
+        if postprocessor:
+            # set postprocessor function if found in the list (XML_POST_PROCESSORS)
+            postprocessor = (
+                XML_POST_PROCESSORS[postprocessor]
+                if postprocessor in XML_POST_PROCESSORS
+                else postprocessor
+            )
+            # check if postprocessor is callable
+            if not callable(postprocessor):
+                raise exceptions.CoreError("postprocessor is not callable")
+
+        # convert xml to dict
+        return xmltodict.parse(
+            raw_xml, postprocessor=postprocessor, force_list=force_list
+        )
     except xmltodict.expat.ExpatError:
         raise exceptions.XMLError(
             "An unexpected error happened during the XML parsing."
@@ -199,12 +234,13 @@ def remove_lists_from_xml_dict(xml_dict, max_list_size=0):
         del xml_dict[key_to_delete]
 
 
-def get_template_with_server_dependencies(xsd_string, dependencies):
+def get_template_with_server_dependencies(xsd_string, dependencies, request=None):
     """Return the template with schema locations pointing to the server.
 
     Args:
         xsd_string:
         dependencies:
+        request:
 
     Returns:
 
@@ -217,7 +253,7 @@ def get_template_with_server_dependencies(xsd_string, dependencies):
 
     # validate the schema
     try:
-        error = validate_xml_schema(xsd_tree)
+        error = validate_xml_schema(xsd_tree, request=request)
     except Exception:
         raise exceptions.XSDError("Something went wrong during XSD validation.")
 
@@ -245,22 +281,13 @@ def get_hash(xml_string):
         raise exceptions.XSDError("Something wrong happened during the hashing.")
 
 
-def post_processor(path, key, value):
-    """Called after XML to JSON transformation.
-
-    Parameters:
-        path:
-        key:
-        value:
-
-    Returns:
-    """
-    return key, convert_value(value)
-
-
-def convert_value(value):
+def get_numeric_value(value):
     """Convert the value to the true type
 
+    abc -> "abc"
+    1 -> 1
+    1.0 -> 1.0
+
     Args:
         value:
 
@@ -276,6 +303,44 @@ def convert_value(value):
             return value
 
 
+def get_string_and_numeric_values(value):
+    """Get string and numeric values
+
+    abc -> "abc"
+    1 -> ("1", 1)
+    1.0 -> ("1.0", 1.0)
+
+    Args:
+        value:
+
+    Returns:
+
+    """
+    try:
+        return value, int(value)
+    except (ValueError, TypeError):
+        try:
+            return value, float(value)
+        except (ValueError, TypeError):
+            return value
+
+
+def numeric_post_processor(path, key, value):
+    """Convert to numeric values"""
+    return key, get_numeric_value(value)
+
+
+def numeric_and_string_post_processor(path, key, value):
+    """Convert to string and numeric values"""
+    return key, get_string_and_numeric_values(value)
+
+
+XML_POST_PROCESSORS = {
+    "NUMERIC": numeric_post_processor,
+    "NUMERIC_AND_STRING": numeric_and_string_post_processor,
+}
+
+
 def get_imports_and_includes(xsd_string):
     """Get a list of imports and includes in the file.
 
@@ -501,3 +566,32 @@ def validate_xpath(xpath):
         xml_utils_xpath.validate_xpath(xpath)
     except xml_utils_exceptions.XPathError as e:
         raise exceptions.XMLError(str(e))
+
+
+def get_content_by_xpath(xml_string, xpath, namespaces=None):
+    """Get list of xml content by xpath
+
+    Args:
+        xml_string:
+        xpath:
+        namespaces:
+
+    Returns:
+
+    """
+    # Build lxml tree from xml string
+    xsd_tree = XSDTree.build_tree(xml_string)
+    # Get values at xpath
+    values_list = xsd_tree.xpath(xpath, namespaces=namespaces)
+
+    # Build list of string values
+    str_values_list = list()
+    # Iterate through all xml elements found
+    for value in values_list:
+        # Get string value for element
+        str_value = value if isinstance(value, str) else XSDTree.tostring(value)
+        # Add value to list
+        str_values_list.append(str_value)
+
+    # Return list of string values found at xpath
+    return str_values_list
