@@ -1,24 +1,21 @@
 """
     Common ajax
 """
-import json
 
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
-from django.http.response import HttpResponse, HttpResponseBadRequest, JsonResponse
+from django.http.response import JsonResponse
 from django.urls import reverse_lazy
-from django.utils.html import escape
+from django.utils.decorators import method_decorator
 from django_mongoengine.views import UpdateView, DeleteView, CreateView
 
 from core_main_app.commons import exceptions
-from core_main_app.components.template import api as template_api
 from core_main_app.components.template_version_manager import (
     api as template_version_manager_api,
 )
 from core_main_app.components.template_version_manager.models import (
     TemplateVersionManager,
 )
-from core_main_app.components.version_manager import api as version_manager_api
 from core_main_app.views.admin.forms import EditTemplateForm
 
 
@@ -184,6 +181,7 @@ class DeleteObjectModalView(DeleteView):
         return {"path": "core_main_app/common/js/modals/delete.js", "is_raw": False}
 
 
+@method_decorator(login_required, name="dispatch")
 class EditTemplateVersionManagerView(EditObjectModalView):
     form_class = EditTemplateForm
     document = TemplateVersionManager
@@ -194,7 +192,7 @@ class EditTemplateVersionManagerView(EditObjectModalView):
         # Save treatment.
         try:
             template_version_manager_api.edit_title(
-                self.object, form.cleaned_data.get("title")
+                self.object, form.cleaned_data.get("title"), request=self.request
             )
         except exceptions.NotUniqueError:
             form.add_error(
@@ -204,156 +202,3 @@ class EditTemplateVersionManagerView(EditObjectModalView):
             )
         except Exception as e:
             form.add_error(None, str(e))
-
-
-@login_required
-def disable_version_manager(request):
-    """Disable a version manager.
-
-    Args:
-        request:
-
-    Returns:
-
-    """
-    try:
-        version_manager = version_manager_api.get(request.GET["id"])
-        version_manager_api.disable(version_manager)
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-    return HttpResponse(json.dumps({}), content_type="application/javascript")
-
-
-@login_required
-def restore_version_manager(request):
-    """Restore a disabled version manager.
-
-    Args:
-        request:
-
-    Returns:
-
-    """
-    try:
-        version_manager = version_manager_api.get(request.GET["id"])
-        version_manager_api.restore(version_manager)
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-    return HttpResponse(json.dumps({}), content_type="application/javascript")
-
-
-@login_required
-def disable_template_version_from_version_manager(request):
-    """Disable a template version of a version manager.
-
-    Args:
-        request:
-
-    Returns:
-
-    """
-    try:
-        disable_version_of_version_manager(template_api.get(request.GET["id"]))
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-    return HttpResponse(json.dumps({}), content_type="application/javascript")
-
-
-def disable_version_of_version_manager(version):
-    """Disable a version of a version manager.
-
-    Args:
-        version:
-
-    Returns:
-
-    """
-    try:
-        version_manager_api.disable_version(version)
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-
-@login_required
-def restore_template_version_from_version_manager(request):
-    """Restore a disabled template version of a version manager.
-
-    Args:
-        request:
-
-    Returns:
-
-    """
-    try:
-        restore_version_from_version_manager(template_api.get(request.GET["id"]))
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-    return HttpResponse(json.dumps({}), content_type="application/javascript")
-
-
-def restore_version_from_version_manager(version):
-    """Restore a disabled version of a version manager.
-
-    Args:
-        version:
-
-    Returns:
-
-    """
-    try:
-        version_manager_api.restore_version(version)
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-
-@login_required
-def set_current_template_version_from_version_manager(request):
-    """Set the current version of a template.
-
-    Args:
-        request:
-
-    Returns:
-
-    """
-    try:
-        set_current_version_from_version_manager(template_api.get(request.GET["id"]))
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
-
-    return HttpResponse(json.dumps({}), content_type="application/javascript")
-
-
-def set_current_version_from_version_manager(version):
-    """Set the current version of a version manager.
-
-    Args:
-        version:
-
-    Returns:
-
-    """
-    try:
-        version_manager_api.set_current(version)
-    except Exception as e:
-        return HttpResponseBadRequest(
-            escape(str(e)), content_type="application/javascript"
-        )
