@@ -3,12 +3,15 @@
 """
 from abc import ABCMeta
 
-from django.urls import reverse
+from django.contrib.auth.decorators import login_required
 from django.http import HttpResponseBadRequest, HttpResponseForbidden
 from django.http.response import HttpResponseRedirect
+from django.urls import reverse
+from django.utils.decorators import method_decorator
 from django.utils.html import escape as html_escape
 from django.views.generic import View
 
+from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons import exceptions
 from core_main_app.commons.exceptions import DoesNotExist
 from core_main_app.components.data import api as data_api
@@ -20,15 +23,12 @@ from core_main_app.components.template_xsl_rendering import (
 from core_main_app.components.version_manager import api as version_manager_api
 from core_main_app.components.workspace import api as workspace_api
 from core_main_app.components.xsl_transformation import api as xslt_transformation_api
-from core_main_app.components.xsl_transformation.models import XslTransformation
-from core_main_app.settings import INSTALLED_APPS
 from core_main_app.utils import group as group_utils
 from core_main_app.utils.labels import get_data_label
 from core_main_app.utils.rendering import admin_render
 from core_main_app.utils.rendering import render
-from core_main_app.views.admin.forms import UploadXSLTForm, TemplateXsltRenderingForm
-from bson import ObjectId
 from core_main_app.utils.view_builders import data as data_view_builder
+from core_main_app.views.admin.forms import TemplateXsltRenderingForm
 
 
 class CommonView(View, metaclass=ABCMeta):
@@ -51,6 +51,7 @@ class CommonView(View, metaclass=ABCMeta):
         return self.administration
 
 
+@method_decorator(login_required, name="dispatch")
 class EditWorkspaceRights(CommonView):
     """
     Edit workspace rights
@@ -135,8 +136,6 @@ class EditWorkspaceRights(CommonView):
             "template": "core_main_app/user/workspaces/list/edit_rights_table.html",
             "action_read": "action_read",
             "action_write": "action_write",
-            "user": "user",
-            "group": "group",
         }
 
         if workspace_api.is_workspace_public(workspace):
@@ -202,17 +201,25 @@ class ViewData(CommonView):
 
         try:
             data_object = data_api.get_by_id(data_id, request.user)
-            page_context = data_view_builder.build_page(data_object)
+            page_context = data_view_builder.build_page(
+                data_object, display_download_options=True
+            )
 
             return data_view_builder.render_page(
-                request, self.common_render, page_context
+                request, self.common_render, self.template, page_context
             )
         except exceptions.DoesNotExist:
             error_message = "Data not found"
+            status_code = 404
         except exceptions.ModelError:
             error_message = "Model error"
+            status_code = 400
+        except AccessControlError:
+            error_message = "Access Forbidden"
+            status_code = 403
         except Exception as e:
             error_message = str(e)
+            status_code = 400
 
         return self.common_render(
             request,
@@ -220,49 +227,12 @@ class ViewData(CommonView):
             context={
                 "error": "Unable to access the requested "
                 + get_data_label()
-                + ": {}.".format(error_message)
+                + ": {}.".format(error_message),
+                "status_code": status_code,
             },
         )
 
 
-class XSLTView(View):
-    """XSLT view."""
-
-    @staticmethod
-    def get(request, *args, **kwargs):
-        modals = [
-            "core_main_app/common/xslt/list/modals/edit.html",
-            "core_main_app/common/xslt/list/modals/delete.html",
-        ]
-
-        assets = {
-            "js": [
-                {
-                    "path": "core_main_app/common/js/xslt/list/modals/edit.js",
-                    "is_raw": False,
-                },
-                {
-                    "path": "core_main_app/common/js/xslt/list/modals/delete.js",
-                    "is_raw": False,
-                },
-            ],
-        }
-
-        context = {
-            "object_name": "XSLT",
-            "xslt": xslt_transformation_api.get_all(),
-            "update_url": reverse("core_main_app_upload_xslt"),
-        }
-
-        return render(
-            request,
-            "core_main_app/common/xslt/list.html",
-            modals=modals,
-            assets=assets,
-            context=context,
-        )
-
-
 def read_xsd_file(xsd_file):
     """Return the content of the file uploaded using Django FileField.
 
@@ -275,59 +245,7 @@ def read_xsd_file(xsd_file):
     return xsd_file.read().decode("utf-8")
 
 
-class UploadXSLTView(View):
-    """Upload XSLT view."""
-
-    form_class = UploadXSLTForm
-    template_name = "core_main_app/common/xslt/upload.html"
-    object_name = "XSLT"
-
-    def __init__(self, **kwargs):
-        super(UploadXSLTView, self).__init__(**kwargs)
-        self.context = {}
-        self.context.update({"object_name": self.object_name})
-
-    def get(self, request, *args, **kwargs):
-        self.context.update({"upload_form": self.form_class()})
-        return render(request, self.template_name, context=self.context)
-
-    def post(self, request, *args, **kwargs):
-        form = self.form_class(request.POST, request.FILES)
-        self.context.update({"upload_form": form})
-
-        if form.is_valid():
-            return self._save_xslt(request)
-        else:
-            # Display error from the form
-            return render(request, self.template_name, context=self.context)
-
-    def _save_xslt(self, request):
-        """Save an XSLT.
-
-        Args:
-            request: Request.
-
-        """
-        try:
-            # get the XSLT name
-            name = request.POST["name"]
-            # get the file from the form
-            xsd_file = request.FILES["upload_file"]
-            # read the content of the file
-            xsd_data = read_xsd_file(xsd_file)
-            xslt = XslTransformation(
-                name=name, filename=xsd_file.name, content=xsd_data
-            )
-            xslt_transformation_api.upsert(xslt)
-
-            return HttpResponseRedirect(reverse("core_main_app_xslt"))
-        except Exception as e:
-            self.context.update({"errors": html_escape(str(e))})
-            return render(
-                request, "core_main_app/common/xslt/upload.html", context=self.context
-            )
-
-
+@method_decorator(login_required, name="dispatch")
 class TemplateXSLRenderingView(View):
     """Template XSL rendering view."""
 
@@ -352,11 +270,13 @@ class TemplateXSLRenderingView(View):
         """
         template_id = kwargs.pop("template_id")
         # Get the template
-        template = template_api.get(template_id)
+        template = template_api.get(template_id, request=request)
         # Get template information (version)
-        version_manager = version_manager_api.get_from_version(template)
+        version_manager = version_manager_api.get_from_version(
+            template, request=request
+        )
         version_number = version_manager_api.get_version_number(
-            version_manager, template_id
+            version_manager, template_id, request=request
         )
         try:
             # Get the existing configuration to build the form
@@ -365,7 +285,7 @@ class TemplateXSLRenderingView(View):
             )
             data = {
                 "id": template_xsl_rendering.id,
-                "template": template.id,
+                "template": str(template.id),
                 "list_xslt": template_xsl_rendering.list_xslt.id
                 if template_xsl_rendering.list_xslt
                 else None,
@@ -381,7 +301,7 @@ class TemplateXSLRenderingView(View):
         except (Exception, exceptions.DoesNotExist):
             # If no configuration, new form with pre-selected fields.
             data = {
-                "template": template.id,
+                "template": str(template.id),
                 "list_xslt": None,
                 "default_detail_xslt": None,
                 "list_detail_xslt": None,
@@ -470,9 +390,11 @@ class TemplateXSLRenderingView(View):
                 list_detail_xslt=list_detail_xslt,
             )
 
-            template = template_api.get(request.POST.get("template"))
+            template = template_api.get(request.POST.get("template"), request=request)
             # Get template information (version)
-            version_manager = version_manager_api.get_from_version(template)
+            version_manager = version_manager_api.get_from_version(
+                template, request=request
+            )
             return HttpResponseRedirect(
                 reverse(self.save_redirect, args=[version_manager.id])
             )
