@@ -16,7 +16,7 @@ from rest_framework.status import HTTP_405_METHOD_NOT_ALLOWED
 
 import core_main_app.components.web_page_login.api as web_page_login_api
 from core_main_app.components.version_manager import api as version_manager_api
-from core_main_app.settings import INSTALLED_APPS
+from core_main_app.settings import INSTALLED_APPS, PASSWORD_RESET_DOMAIN_OVERRIDE
 from core_main_app.utils.markdown_parser import parse
 from core_main_app.utils.rendering import render
 from core_main_app.views.user.forms import LoginForm
@@ -198,7 +198,7 @@ def manage_template_versions(request, version_manager_id):
     """
     try:
         # get the version manager
-        version_manager = version_manager_api.get(version_manager_id)
+        version_manager = version_manager_api.get(version_manager_id, request=request)
 
         if not request.user.is_staff and version_manager.user != str(request.user.id):
             raise Exception("You do not have the rights to perform this action.")
@@ -317,6 +317,7 @@ def custom_reset_password(
                 "request": request,
                 "html_email_template_name": html_email_template_name,
                 "extra_email_context": extra_email_context,
+                "domain_override": PASSWORD_RESET_DOMAIN_OVERRIDE,
             }
             form.save(**opts)
             return HttpResponseRedirect(post_reset_redirect)
@@ -454,3 +455,15 @@ def custom_password_reset_complete(
         context.update(extra_context)
 
     return render(request, template_name, context=context, assets=assets)
+
+
+def saml2_failure(request, exception=None, status=403, **kwargs):
+    """Renders a simple template with an error message."""
+
+    return render(
+        request,
+        "core_main_app/user/login/saml2_error.html",
+        context={
+            "with_website_features": "core_website_app" in INSTALLED_APPS,
+        },
+    )
