@@ -4,9 +4,10 @@ import unittest
 
 from mock.mock import patch
 
+from core_main_app.access_control.exceptions import AccessControlError
+from core_main_app.commons.exceptions import QueryError
 from core_main_app.components.data import api as data_api
 from core_main_app.components.data.models import Data
-from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.utils.integration_tests.integration_base_test_case import (
     MongoIntegrationBaseTestCase,
 )
@@ -15,10 +16,6 @@ from tests.components.data.fixtures.fixtures import AccessControlDataFixture
 
 fixture_data = AccessControlDataFixture()
 
-# NOTE: Uncomment to test in debug
-# from django.conf import settings
-# settings.INSTALLED_APPS = ['core_workspace_app']
-
 
 class TestDataGetById(MongoIntegrationBaseTestCase):
 
@@ -294,6 +291,46 @@ class TestDataExecuteQuery(MongoIntegrationBaseTestCase):
         data_list = data_api.execute_query({}, mock_user)
         self.assertTrue(len(data_list) == 5)
 
+    def test_execute_query_as_superuser_with_unknown_operator_raises_error(self):
+        mock_user = _create_user("1", is_superuser=True)
+        with self.assertRaises(QueryError):
+            data_api.execute_query({"$test": 2}, mock_user)
+
+    def test_execute_query_as_superuser_with_unknown_operator_value_raises_error(self):
+        mock_user = _create_user("1", is_superuser=True)
+        with self.assertRaises(QueryError):
+            data_api.execute_query({"test": "$2"}, mock_user)
+
+    def test_execute_query_as_superuser_with_unknown_operator_in_list_raises_error(
+        self,
+    ):
+        mock_user = _create_user("1", is_superuser=True)
+        with self.assertRaises(QueryError):
+            data_api.execute_query(
+                {"$and": [{"$or": [{"root.element": {"$test": ["1", "2"]}}]}]},
+                mock_user,
+            )
+
+    def test_execute_query_as_superuser_with_unknown_operator_in_value_raises_error(
+        self,
+    ):
+        mock_user = _create_user("1", is_superuser=True)
+        with self.assertRaises(QueryError):
+            data_api.execute_query(
+                {"$and": [{"$or": [{"root.element": {"$in": ["$test", "2"]}}]}]},
+                mock_user,
+            )
+
+    def test_execute_query_as_superuser_with_unknown_operator_in_key_raises_error(
+        self,
+    ):
+        mock_user = _create_user("1", is_superuser=True)
+        with self.assertRaises(QueryError):
+            data_api.execute_query(
+                {"$and": [{"$or": [{"root.$element": {"$in": ["1", "2"]}}]}]},
+                mock_user,
+            )
+
 
 class TestDataDelete(MongoIntegrationBaseTestCase):
 
