@@ -343,6 +343,36 @@ class TestDataDownload(MongoIntegrationBaseTestCase):
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
+    def test_get_with_param_returns_http_200(self):
+        # Arrange
+        user = create_mock_user("1")
+
+        # Act
+        response = RequestMock.do_request_get(
+            data_rest_views.DataDownload.as_view(),
+            user,
+            param={"pk": self.fixture.data_1.id},
+            data={"pretty_print": "false"},
+        )
+
+        # Assert
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+    def test_get_with_param_returns_http_400_when_content_not_well_formatted(self):
+        # Arrange
+        user = create_mock_user("1")
+
+        # Act
+        response = RequestMock.do_request_get(
+            data_rest_views.DataDownload.as_view(),
+            user,
+            param={"pk": self.fixture.data_1.id},
+            data={"pretty_print": "true"},
+        )
+
+        # Assert
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+
 
 class TestExecuteLocalQueryView(MongoIntegrationBaseTestCase):
     fixture = fixture_data_query
@@ -1007,7 +1037,6 @@ class TestDataChangeOwner(MongoIntegrationBaseTestCase):
 
 class TestDataPermissions(MongoIntegrationTransactionTestCase):
     fixture = fixture_data_workspace
-    admin_user = UserFixtures().create_super_user("admin")
 
     def setUp(self):
         """Insert needed data.
@@ -1018,6 +1047,7 @@ class TestDataPermissions(MongoIntegrationTransactionTestCase):
         super().setUp()
         self.fixture.insert_data()
         self.fixture.generate_workspace_with_perm()
+        self.admin_user = UserFixtures().create_super_user("admin")
 
     def test_get_returns_correct_permissions_if_user_is_superuser(self):
         # Arrange
