@@ -13,7 +13,7 @@ from core_main_app.utils.integration_tests.integration_base_test_case import (
     MongoIntegrationBaseTestCase,
 )
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
-from core_main_app.utils.tests_tools.RequestMock import RequestMock
+from core_main_app.utils.tests_tools.RequestMock import RequestMock, create_mock_request
 from tests.components.template_version_manager.fixtures.fixtures import (
     TemplateVersionManagerFixtures,
 )
@@ -227,7 +227,7 @@ class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
 
     def test_get_returns_http_200(self):
         # Arrange
-        user = create_mock_user("1")
+        user = create_mock_user("1", is_superuser=True)
 
         # Act
         response = RequestMock.do_request_get(
@@ -241,7 +241,7 @@ class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
 
     def test_get_returns_tvm(self):
         # Arrange
-        user = create_mock_user("1")
+        user = create_mock_user("1", is_superuser=True)
 
         # Act
         response = RequestMock.do_request_get(
@@ -399,6 +399,7 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
     def test_post_owner_is_user(self):
         # Arrange
         user = create_mock_user("1")
+        mock_request = create_mock_request(user=user)
 
         # Act
         response = RequestMock.do_request_post(
@@ -407,8 +408,10 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
         # get template version manager from posted template
         template_id = response.data["id"]
-        template_object = template_api.get(template_id)
-        template_version_manager = vm_api.get_from_version(template_object)
+        template_object = template_api.get(template_id, request=mock_request)
+        template_version_manager = vm_api.get_from_version(
+            template_object, request=mock_request
+        )
 
         # Assert
         self.assertEqual(template_version_manager.user, user.id)
@@ -555,6 +558,7 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
     def test_post_owner_is_global(self):
         # Arrange
         user = create_mock_user("1", is_staff=True)
+        mock_request = create_mock_request(user=user)
 
         # Act
         response = RequestMock.do_request_post(
@@ -563,8 +567,10 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
 
         # get template version manager from posted template
         template_id = response.data["id"]
-        template_object = template_api.get(template_id)
-        template_version_manager = vm_api.get_from_version(template_object)
+        template_object = template_api.get(template_id, request=mock_request)
+        template_version_manager = vm_api.get_from_version(
+            template_object, request=mock_request
+        )
 
         # Assert
         self.assertEqual(template_version_manager.user, None)
