@@ -10,8 +10,11 @@ INSTALLED_APPS = [
     "django.contrib.sessions",
     "django.contrib.messages",
     "django.contrib.sites",
+    "django.contrib.staticfiles",
     # Extra apps
     "defender",
+    "tz_detect",
+    "menu",
     # Local apps
     "core_main_app",
     "tests",
@@ -36,6 +39,7 @@ MIDDLEWARE = (
     "django.contrib.auth.middleware.AuthenticationMiddleware",
     "django.contrib.messages.middleware.MessageMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
+    "tz_detect.middleware.TimezoneMiddleware",
 )
 
 TEMPLATES = [
@@ -56,6 +60,12 @@ TEMPLATES = [
     },
 ]
 
+LOGIN_URL = "/login"
+STATIC_URL = "/static/"
+ROOT_URLCONF = "tests.urls"
+DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
+CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
+
 PASSWORD_HASHERS = ("django.contrib.auth.hashers.UnsaltedMD5PasswordHasher",)
 
 MOCK_DATABASE_NAME = "db_mock"
@@ -63,21 +73,8 @@ MOCK_DATABASE_HOST = "mongomock://localhost"
 
 DATA_SORTING_FIELDS = ["+title"]
 
-# Password settings for django.contrib.auth validators
-# Specifies the minimum length for passwords.
-PASSWORD_MIN_LENGTH = 12
-# Specifies the minimum amount of required letters in a password.
-PASSWORD_MIN_LETTERS = 1
-# Specifies the minimum amount of required uppercase letters in a password.
-PASSWORD_MIN_UPPERCASE_LETTERS = 1
-# Specifies the minimum amount of required lowercase letters in a password.
-PASSWORD_MIN_LOWERCASE_LETTERS = 1
-# Specifies the minimum amount of required numbers in a password.
-PASSWORD_MIN_NUMBERS = 1
-# Specifies the minimum amount of required symbols in a password.
-PASSWORD_MIN_SYMBOLS = 1
-# Specifies the maximum amount of consecutive characters allowed in passwords.
-PASSWORD_MAX_OCCURRENCE = 5
+CUSTOM_NAME = "Curator"
+ENABLE_SAML2_SSO_AUTH = False
 
 database = Database(MOCK_DATABASE_HOST, MOCK_DATABASE_NAME)
 database.connect()
